@@ -46,6 +46,7 @@ static int initializeLang()
 {
     qputenv("LC_ALL", "en_US");
     qputenv("LANG", "en_US");
+    qputenv("XDG_CURRENT_DESKTOP", "KDE");
     kservice_require_kded = false;
     return 0;
 }
@@ -81,7 +82,7 @@ void KMimeTypeTest::initTestCase()
     }
 
     // Create fake text/plain part with a higher initial preference than the patch part.
-    const QString fakePart = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kservices5/") + "faketextpart.desktop";
+    QString fakePart = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kservices5/") + "faketextpart.desktop";
     const bool mustCreate = !QFile::exists(fakePart);
     if (mustCreate) {
         mustUpdateKSycoca = true;
@@ -96,7 +97,7 @@ void KMimeTypeTest::initTestCase()
     }
 
     // Create fake text/plain ktexteditor plugin.
-    const QString fakePlugin = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kservices5/") + "faketextplugin.desktop";
+    QString fakePlugin = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/kservices5/") + "faketextplugin.desktop";
     const bool mustCreatePlugin = !QFile::exists(fakePlugin);
     if (mustCreatePlugin) {
         mustUpdateKSycoca = true;
@@ -124,6 +125,7 @@ void KMimeTypeTest::initTestCase()
         group.writeEntry("InitialPreference", "50");
         group.writeEntry("Categories", "Qt;KDE;");
     }
+    m_nonKdeApp = QFileInfo(m_nonKdeApp).canonicalFilePath();
 
     // Create fake text/plain app
     m_textPlainApp = QStandardPaths::writableLocation(QStandardPaths::ApplicationsLocation) + QLatin1Char('/') + "fake_textplain_application.desktop";
@@ -139,6 +141,7 @@ void KMimeTypeTest::initTestCase()
         group.writeEntry("InitialPreference", "40");
         group.writeEntry("Categories", "Qt;KDE;");
     }
+    m_textPlainApp = QFileInfo(m_textPlainApp).canonicalFilePath();
 
     if (mustUpdateKSycoca) {
         // Update ksycoca in ~/.kde-unit-test after creating the above
@@ -864,7 +867,7 @@ void KMimeTypeTest::testSortByComment()
 {
     QBENCHMARK {
         KMimeType::List sortedList = KMimeType::allMimeTypes();
-        qSort(sortedList.begin(), sortedList.end(), LessMimeType_ByComment());
+        std::sort(sortedList.begin(), sortedList.end(), LessMimeType_ByComment());
     }
 }
 
